@@ -1,5 +1,5 @@
 
-from wcf.packages.demo import test,TestConfigBase,PredictConfigBase
+from wcf.packages.template import test,TestConfigBase,PredictConfigBase
 
 class PredictConfig(PredictConfigBase):
 
